# django-naivedatetimefield
![build status](https://api.travis-ci.org/camflan/django-naivedatetimefield.svg?branch=master)
[![PyPI version](https://badge.fury.io/py/django-naivedatetimefield.svg)](https://pypi.org/project/django-naivedatetimefield/2.0.0)


NaiveDateTimeField offers the ability to store a naive timestamp, useful for baking in a local timestamp.

## Installation

`pip install django-naivedatetimefield`


## Contributors
- [Camron Flanders](https://github.com/camflan)
- [Alex Hill](https://github.com/AlexHill)
- [Lincoln Puzey](https://github.com/LincolnPuzey)
